@@ -21,11 +21,10 @@ sed -e "s/@PQXXVERSION@/$PQXXVERSION/g" configure.ac.in >configure.ac
 # Generate test/Makefile.am
 ./tools/maketestam.pl test >test/Makefile.am
 
-# Generate win32/test.mak (adding carriage returns to make it MS-DOS format)
+# Generate Windows makefiles (adding carriage returns to make it MS-DOS format)
 ./tools/maketestvcmak.pl test | sed -e 's/$/\r/' >win32/test.mak
-
-# Generate win32/libpqxx.mak
 ./tools/makevcmake.pl src | sed -e 's/$/\r/' >win32/libpqxx.mak
+./tools/makemingwmak.pl src | sed -e 's/$/\r/' >win32/MinGW.mak
 
 autoheader
 
