@@ -84,7 +84,7 @@ public:
 
   void OnAbort(const char Reason[]) throw ()
   {
-    cerr << "(Expected) Transactor " << Name() << " failed: " << Reason << endl;
+    cout << "(Expected) Transactor " << Name() << " failed: " << Reason << endl;
   }
 
   void OnCommit()
@@ -125,7 +125,7 @@ int main(int argc, char *argv[])
     }
     catch (const exception &e)
     {
-      cerr << "(Expected) Doomed transaction failed: " << e.what() << endl;
+      cout << "(Expected) Doomed transaction failed: " << e.what() << endl;
     }
 
     pair<int,int> After;
